@@ -107,8 +107,13 @@ fill_advanced_table (Longcat *plugin,
       GTK_SHRINK | GTK_FILL, 0, 0, 0);
 
   range = g_strdup_printf ("0:%" G_GUINT32_FORMAT, G_MAXUINT32);
-  widget_text = g_strdup_printf ("%" G_GUINT32_FORMAT,
-      g_value_get_uint (default_port));
+
+  /* Workaround for now. */
+  if (default_port != NULL)
+    widget_text = g_strdup_printf ("%" G_GUINT32_FORMAT,
+        g_value_get_uint (default_port));
+  else
+    widget_text = g_strdup ("1863");
 
   widget = GTK_WIDGET (g_object_new (RTCOM_TYPE_PARAM_INT,
           "field", "port",
